@@ -1,13 +1,11 @@
 from pathlib import Path
 from typing import List
 
-from cognite.airworkflow.model.project import Project
-
 
 class Deployment:
     def __init__(
         self,
-        project: Project,
+        project: str,
         code_path: Path,
         version: str,
         secret_names: List[str],
